package sbhpfv1

import (
	"io"

	"git.zervo.org/FLUX/GoSBHPF/pkg/seekablebuffer"
)

// SerializeNodeBuffered serializes a node object into a SBHPF node.
// It is a wrapper around SerializeNode that temporarily stores the serialized nodes in a seekable memory buffer.
// This provides serialization compatibility with non-seekable writers, at the cost of increased memory usage.
func SerializeNodeBuffered(w io.Writer, node *Node) error {
	buf := &seekablebuffer.Buffer{}
	if err := SerializeNode(buf, node); err != nil {
		return err
	}

	_, err := io.Copy(w, buf)
	return err
}

// SerializeBuffered serializes a root node object into a complete SBHPF tree.
// It is a wrapper around Serialize that temporarily stores the serialized data in a seekable memory buffer.
// This provides serialization compatibility with non-seekable writers, at the cost of increased memory usage.
func SerializeBuffered(w io.Writer, node *Node) error {
	buf := &seekablebuffer.Buffer{}
	if err := Serialize(buf, node); err != nil {
		return err
	}

	_, err := io.Copy(w, buf)
	return err
}
